@@ -61,7 +61,9 @@ class MySQLClient:
         row = []
         for d in data.keys():
             col.append(d)
-            row.append('"'+self.strclass.html_escape(data[d])+'"')
+            value=self.strclass.html_escape(data[d])
+            value=value.replace('\\','\\\\')
+            row.append('"'+value+'"')
         sql = 'INSERT INTO %s (%s) VALUES (%s)' % (
             table,
             ','.join(col),
@@ -97,7 +99,7 @@ class MySQLClient:
         result = False
         values = []
         for d in data:
-            val = '(%s)' % (','.join(str(v) if type(v)!= str else "'"+v+"'" for v in d))
+            val = '(%s)' % (','.join(str(v) if type(v)!= str else "'"+self.strclass.html_escape(v).replace('\\','\\\\')+"'" for v in d))
             values.append(val)
         sql = 'INSERT INTO %s (%s) VALUES %s' % (table, ','.join(field),
                                                  ','.join(values))
@@ -117,16 +119,18 @@ class MySQLClient:
             self.close()
         return result
 
-    def fetch(self, fields: list, table: str, query: str = '', orderby: dict = None, close: bool = True):
+    def fetch(self, fields: list, table: str, query: str = '', orderby: dict = None, limit: int = 0, close: bool = True):
         '''
         查询数据，查询条件数据建议使用html_escape转码保证数据查询安全
         :param fields 要查询的字段名
         :param table 表名
         :param query 查询条件，默认为空
         :param orderby 排序，默认为空，例：{'sort':'desc'}
+        :param limit 查询条数，默认0则不限制条数
         :param close 是否自动关闭数据库连接，默认True
         :return {list} 如没有查询结果则返回None
         '''
+        print('haha')
         where_str = ''
         if query != '':
             where_str = 'WHERE %s' % query
@@ -136,19 +140,27 @@ class MySQLClient:
             for key in orderby.keys():
                 orderby_arr.append('%s %s' % (key, orderby[key]))
             orderby_str = 'ORDER BY ' + ','.join(orderby_arr)
-        sql = 'SELECT %s FROM %s %s %s' % (
+        limit_str=''
+        if limit!=0:
+            limit_str='limit %s' % limit
+        sql = 'SELECT %s FROM %s %s %s %s' % (
             ','.join(fields),
             table,
             where_str,
-            orderby_str
+            orderby_str,
+            limit_str
         )
-        try:
-            # 执行SQL语句
-            self.cursor.execute(sql)
-            # 获取所有记录列表
-            results = self.cursor.fetchall()
-        except:
-            print("Error: unable to fetch data")
+        # 执行SQL语句
+        self.cursor.execute(sql)
+        # 获取所有记录列表
+        results = self.cursor.fetchall()
+        # try:
+        #     # 执行SQL语句
+        #     self.cursor.execute(sql)
+        #     # 获取所有记录列表
+        #     results = self.cursor.fetchall()
+        # except:
+        #     print("Error: unable to fetch data")
         # 关闭数据库连接
         if close:
             self.close()
@@ -161,7 +173,9 @@ class MySQLClient:
         for result in results:
             col_data = {}
             for col in range(col_count):
-                col_data[fields[col]] = result[col]
+                # 处理查询条件中特殊字符``
+                field = fields[col].replace('`', '')
+                col_data[field] = result[col]
             res_data.append(col_data)
         return res_data
 
@@ -171,7 +185,7 @@ class MySQLClient:
         :param table 表名
         :param query where后的查询条件，例：id=1 and name='张三'
         :param close 是否自动关闭数据库连接，默认True
-        :return {list} 如没有查询结果则返回None
+        return:int 结果条数
         '''
         where_str = ''
         if query != '':
@@ -196,7 +210,7 @@ class MySQLClient:
 
     def update(self, table: str, set: dict, query: str = '', close: bool = True):
         '''
-        更新数据，查询条件数据建议使用html_escape转码保证数据查询安全
+        更新数据，插入内容均自动做html_escape处理
         :param table 表名
         :param set 需要修改的内容
         :param query 查询条件，默认为空
@@ -209,8 +223,11 @@ class MySQLClient:
             where_str = 'WHERE %s' % query
         set_list = []
         for key in set.keys():
+            value = self.strclass.html_escape(set[key])
+            # 将字符串中的\替换为\\，防止插入mysql时\符号消失
+            value = value.replace('\\', '\\\\')
             set_list.append(
-                '%s="%s"' % (key, self.strclass.html_escape(set[key]))
+                '%s="%s"' % (key, value)
             )
         sql = 'UPDATE %s SET %s %s' % (
             table,
