@@ -112,13 +112,17 @@ class StrClass:
             return ''
         return html.escape(value)
 
-    def html_unescape(self, value: str):
+    def html_unescape(self, value: str, b_json: bool = False):
         '''
         对传输的值进行html解码
         :param value 需要转换的字符串
+        :param b_json 是否将json字符串转化为Python对象
         :return 解码后的字符串
         '''
-        return html.unescape(value)
+        value=html.unescape(value)
+        if b_json:
+            value=json.loads(value)
+        return value
 
     # def symbol_replace(self,value):
     #     '''
@@ -144,7 +148,7 @@ class JsonClass:
         :param data 字典类型数据
         :return {str} 转换后的json格式字符串
         '''
-        return json.dumps(data)
+        return json.dumps(data,ensure_ascii=False)
 
     def jsonToLoads(self, jsonstr: str):
         '''
